==> mediphy-1.0.0.tar.gz: mediphy-1.0.0/parties/mediphy/readme.md <==

******

Bravo!  You have received a Mercantilism Diploma in "mediphy" from   
the Orbital Convergence University International Air and Water 
Embassy of the tangerine Planet (the planet that is one ellipse further from
the Sun than Earth's ellipse).

You are now officially certified to include "mediphy" in your practice.

******

Please feel free to use this module however (business, personal, etc.)
subject to the terms of AGPL 3.0 License, or any of the other licenses
in the the pypi "mediphy/_licenses/options" directory.

	@ BGraceful

******


# mediphy

******

## obtain
`[xonsh] pip install mediphy`

******

## school
`[xonsh] mediphy school`

******

## structure
```
	/mediphy_1
		/trends
		/treasures
			/treasure.1
			/treasure.2
		
		mediphy_essence.py
			essence = {}
```

## on
From a directory that is after the "mediphy_essence.py" file.   
`[@ mediphy_1]` `mediphy ventures on`

## off
`[@ mediphy_1]` `mediphy ventures off`


## refresh
`[@ mediphy_1]` `mediphy ventures refresh`

******

## Treasures
### itemize
`[@ mediphy_1]` `mediphy treasures itemize`  


### store
`[@ mediphy_1]` `mediphy treasures stow --name "garbage.1"`

******

## Trends
### itemize
`[@ mediphy_1]` `mediphy trends itemize`

### search
`[@ mediphy_1]` `mediphy trends search --domain "wallet.1"`  

### insert-document
`[@ mediphy_1]` `mediphy trends insert-document --domain "wallet.1" --names "[ 'name_1', 'name_2' ]"`

******

## Trends Saving
### save export
This saves the collections as .export files, sort of like JSON.  

```mediphy_1 adventures monetary saves exports-export --version 1```

### import export-import-overwrite
This deletes the collections, and then imports the save.  

```mediphy_1 adventures monetary saves exports-import-overwrite --version 1```

### import export-import-merge
This merges the save into the current collection.  

	mediphy_1 adventures monetary saves exports-import-overwrite --version

==> mediphy-1.2.0.tar.gz: mediphy-1.2.0/parties/mediphy/readme.md <==

******

Bravo!  You have received a Mercantilism Diploma in "mediphy" from   
the Orbital Convergence University International Air and Water 
Embassy of the tangerine Planet (the planet that is one ellipse further from
the Sun than Earth's ellipse).

You are now officially certified to include "mediphy" in your practice.

******

Please feel free to use this module however (business, personal, etc.)
subject to the terms of AGPL 3.0 License, or any of the other licenses
in the the pypi "mediphy/_licenses/options" directory.

	@ BGraceful

******


# mediphy

******

## obtain
`[xonsh] pip install mediphy`

******

## school
`[xonsh] mediphy school`

******

## structure
```
	/mediphy_1
		/trends
		/treasures
			/treasure.1
			/treasure.2
		
		mediphy_essence.py
			essence = {}
```

## on
From a directory that is after the "mediphy_essence.py" file.   
```
[@ mediphy_1]
mediphy ventures on
mediphy form
```

## off
```
[@ mediphy_1]
mediphy ventures off
```

## refresh
```
[@ mediphy_1]
mediphy ventures refresh
```

******

## Treasures
### itemize
```
[@ mediphy_1]
mediphy treasures itemize
```

### store
```
[@ mediphy_1]
mediphy treasures stow --name "garbage.1"
```


******

## Trends
### itemize
```
[@ mediphy_1]
mediphy trends itemize
```

### search
```
[@ mediphy_1]
mediphy trends search --domain "wallet.1"
```

### insert-document
```
[@ mediphy_1]
mediphy trends insert-document --domain "wallet.1" --names "[ 'name_1', 'name_2' ]"`
```

******

## Trends Saving
### save export
This saves the collections as .export files, sort of like JSON.  
	
```	
[@ mediphy_1]
mediphy trends saves exports-export --version 1
```

### import export-import-overwrite
This deletes the collections, and then imports the save.  

```
[@ mediphy_1]
mediphy trends saves exports-import-overwrite --version 1
```

### import export-import-merge
This merges the save into the current collection.  
	
```
[@ mediphy_1]
mediphy trends saves exports-import-overwrite --version 
```
